package de.fhdw.gaming.ipspiel23.memory;

import de.fhdw.gaming.core.domain.Player;
import de.fhdw.gaming.core.domain.State;

/**
 * Represents a game state with support for memory management.
 * <p>
 * Provides access to the {@link IGameMemoryProvider} that is used to store and retrieve decisions and round data.
 * </p>
 * 
 * @param <P> The player type.
 * @param <S> The state type.
 * @param <ROUND_DATA> The round data type.
 */
public interface IMemoryState<P extends Player<P>, S extends State<P, S>, ROUND_DATA> extends State<P, S> {
    
    /**
     * Returns the {@link IGameMemoryProvider} to be used to store and retrieve decisions and round data.
     */
    IGameMemoryProvider getMemoryProvider();
}
